@@ -92,7 +92,7 @@ def _recv_ready(sock, events):  # pylint: disable-msg=W0613
             if err.errno == zmq.EAGAIN:
                 return
             else:
-                raise
+                raise  # pragma: no cover
 
         # No use making this non-blocking - 0MQ cannot handle 2 reads at time
         sock.send_multipart([constants.PROTO_STATUS_SUCCESS,
